@@ -1,4 +1,4 @@
-# $Id: wcloud.py 1343 2015-07-24 23:49:19Z mwall $
+# $Id: wcloud.py 1391 2015-12-28 14:51:29Z mwall $
 # Copyright 2014 Matthew Wall
 
 """
@@ -45,7 +45,7 @@ import weewx.units
 import weewx.wxformulas
 from weeutil.weeutil import to_bool, accumulateLeaves
 
-VERSION = "0.8"
+VERSION = "0.10"
 
 if weewx.__version__ < "3":
     raise weewx.UnsupportedFeature("weewx 3 is required, found %s" %
@@ -257,7 +257,7 @@ class WeatherCloudThread(weewx.restx.RESTThread):
         rec['winddiravg'] = _get_winddiravg(dbm, record['dateTime'])
 
         # ensure wind direction is in [0,359]
-        if rec['windDir'] > 359:
+        if 'windDir' in rec and rec['windDir'] > 359:
             rec['windDir'] -= 360
         if rec['winddiravg'] > 359:
             rec['winddiravg'] -= 360
